﻿using ApiLog.Act.Models.Log;
using ApiLog.Act.Models.Mongo;
using MongoDB.Driver;
using PushPlatform.Common.Util;
using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;

namespace ApiLog.Act.DAL.Mongo
{
    public class APILogsMongRepository
    {
        private MongoLogRepository mongoRep = new MongoLogRepository();

        /// <summary>
        /// 集合名称
        /// </summary>
        private static readonly string _CollectionName = "PushAPILogs";

        #region 新增请求日志

        /// <summary>
        /// 新增请求日志
        /// </summary>
        /// <param name="param"></param>
        /// <returns></returns>
        public async Task<AddRequestLogModel> AddRequestLogAsync(AddRequestLogParam param)
        {
            PushAPILogs entity = new PushAPILogs();
            ObjectUtil.CopyPropertys(param, entity);
            entity.ID = param.TraceID;
            entity.RequestTime = DateTime.Now;
            mongoRep.Add<PushAPILogs>(entity);
            return new AddRequestLogModel() { RequestTime = entity.RequestTime, TraceID = param.TraceID };
        }

        #endregion

        #region 新增响应日志

        /// <summary>
        /// 新增响应日志
        /// </summary>
        /// <param name="param"></param>
        /// <returns></returns>
        public void AddResponseLog(AddResponseLogParam param)
        {
            var builder = Builders<PushAPILogs>.Filter;
            var filter = builder.Eq(nameof(PushAPILogs.ID), param.ParentTraceID);
            var update = Builders<PushAPILogs>.Update
                .Set(nameof(PushAPILogs.ResponseBody), param.ResponseBody)
                .Set(nameof(PushAPILogs.ResponseTime), DateTime.Now)
                .Set(nameof(PushAPILogs.TimeCost), param.TimeCost);

            if (param.IsError)
            {
                update = update.Set(nameof(PushAPILogs.IsError), param.IsError)
                    .Set(nameof(PushAPILogs.ErrorBody), param.ErrorBody)
                    .Set(nameof(PushAPILogs.ErrorBody), param.ErrorBody);
            }

            mongoRep.Update(_CollectionName.ToLower(),filter, update);
        }
        #endregion
    }
}
